GlobalError

Struct GlobalError 

pub struct GlobalError(/* private fields */);
Available on crate features internal-api-crypto and internal-with-error only.
Helper struct to implement WithError.

Implementations

Source

impl GlobalError

pub const fn new() -> Self

Creates an empty global error.

pub fn with<T>(&self, operation: impl FnOnce() -> T) -> Result<T, Error>

Helper to implement with_error.

This will consume the global error if not empty.

pub fn record<T>(&self, x: Result<T, Error>) -> Option<T>

Records an error.

This will overwrite any previous error that was not consumed yet.